<?php

declare(strict_types=1);

namespace Drupal\tmgmt_ec_etranslation;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element;
use Drupal\tmgmt\TranslatorPluginUiBase;

/**
 * Builds the configuration form for the eTranslation translator.
 */
class ETranslationTranslatorUi extends TranslatorPluginUiBase {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildConfigurationForm($form, $form_state);

    /** @var \Drupal\tmgmt\TranslatorInterface $translator */
    $translator = $form_state->getFormObject()->getEntity();

    $form['username'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Username'),
      '#required' => TRUE,
    ];

    $form['password'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Password'),
      '#required' => TRUE,
    ];

    $form['domain'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Domain'),
      '#required' => TRUE,
    ];

    $form['email'] = [
      '#type' => 'email',
      '#title' => $this->t('Email address'),
      '#description' => $this->t('An optional email address to send the translation results to.'),
      '#required' => FALSE,
    ];

    $form['callback_hostname'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Callback hostname'),
      '#description' => $this->t('An optional hostname to which callbacks are made. You can use this to make callbacks work on private development environments, using a tunneling service like Expose or forwarding service like Request Catcher. Ngrok is considered a security risk by the eTransaction team and should not be used.'),
      '#required' => FALSE,
      '#element_validate' => [[static::class, 'validateHostname']],
    ];

    $form['use_queue'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Use queue'),
      '#description' => $this->t('Queue the process for incoming translations.'),
    ];

    $config = \Drupal::config($translator->getConfigDependencyName());
    foreach (Element::children($form) as $child) {
      $key = 'settings.' . $child;
      $value = $config->get($key);
      $original = $config->getOriginal($key, FALSE);

      if ($value !== $original) {
        $form[$child]['#placeholder'] = $value;
        $form[$child]['#disabled'] = TRUE;
        $form[$child]['#description'] = $this->t('This config cannot be changed because it is overridden.');
      }
      else {
        $form[$child]['#default_value'] = $value;
      }
    }

    return $form;
  }

  /**
   * Validates the hostname callback.
   *
   * @param array $element
   *   The element to validate.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   */
  public static function validateHostname(array $element, FormStateInterface $form_state): void {
    $value = $element['#value'];

    if (!empty($value) && !filter_var($value, FILTER_VALIDATE_DOMAIN, FILTER_FLAG_HOSTNAME)) {
      $form_state->setError($element,
        t('Please enter a valid hostname, like "domain.com". Do not include "http://" or "https://".')
      );
    }
  }

}
