<?php

declare(strict_types=1);

namespace Drupal\tmgmt_ec_etranslation\Plugin\QueueWorker;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\tmgmt_ec_etranslation\TranslationResponseProcessorInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Processes incoming translations.
 *
 * @QueueWorker(
 *   id = \Drupal\tmgmt_ec_etranslation\Plugin\QueueWorker\TranslationQueueWorker::ID,
 *   title = @Translation("Processes incoming translations"),
 *   cron = {"time" = 60}
 * )
 */
class TranslationQueueWorker extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  public const ID = 'tmgmt_ec_etranslation_translation';

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected EntityTypeManagerInterface $entityTypeManager;

  /**
   * The translation response processor.
   *
   * @var \Drupal\tmgmt_ec_etranslation\TranslationResponseProcessorInterface
   */
  protected TranslationResponseProcessorInterface $translationResponseProcessor;

  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    EntityTypeManagerInterface $entity_type_manager,
    TranslationResponseProcessorInterface $translation_response_processor,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->entityTypeManager = $entity_type_manager;
    $this->translationResponseProcessor = $translation_response_processor;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(
    ContainerInterface $container,
    array $configuration,
    $plugin_id,
    $plugin_definition,
  ): self {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager'),
      $container->get('tmgmt_ec_etranslation.translation_response_processor'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data): void {
    [$jobItemId, $key, $response] = $data;

    $jobItem = $this->entityTypeManager
      ->getStorage('tmgmt_job_item')
      ->load($jobItemId);
    if (!$jobItem) {
      return;
    }

    $this->translationResponseProcessor->process($jobItem, $key, $response);
  }

}
