<?php

namespace Drupal\tmgmt_ec_etranslation;

use Drupal\tmgmt\Data;
use Drupal\tmgmt\JobItemInterface;
use Psr\Log\LoggerInterface;

/**
 * Processes translation responses.
 */
class TranslationResponseProcessor implements TranslationResponseProcessorInterface {

  /**
   * Logger service.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected LoggerInterface $logger;

  /**
   * The tmgmt data service.
   *
   * @var \Drupal\tmgmt\Data
   */
  protected Data $tmgmtData;

  /**
   * Text validator service.
   *
   * @var \Drupal\tmgmt_ec_etranslation\TextValidatorInterface
   */
  protected TextValidatorInterface $textValidator;

  public function __construct(
    LoggerInterface $logger,
    Data $tmgmtData,
    TextValidatorInterface $textValidator,
  ) {
    $this->logger = $logger;
    $this->tmgmtData = $tmgmtData;
    $this->textValidator = $textValidator;
  }

  /**
   * Processes a translation response.
   *
   * @param \Drupal\tmgmt\JobItemInterface $jobItem
   *   Job item.
   * @param string $key
   *   The response key or identifier (external-reference).
   * @param string $response
   *   The raw JSON response content.
   */
  public function process(JobItemInterface $jobItem, string $key, string $response): void {
    $translatableFields = $this->tmgmtData->filterTranslatable($jobItem->getData());

    if ($this->textValidator->isHtml($translatableFields[$key]['#text']) ||
      !$this->textValidator->canTextToTranslateBeUsed($translatableFields[$key]['#text'])) {
      $translation['#text'] = base64_decode($response);
    }
    else {
      $translation['#text'] = $response;
    }

    $this->logger->notice('Translation received for job item @id: @translation', [
      '@id' => $jobItem->id(),
      '@translation' => $translation['#text'],
    ]);

    $jobItem->addTranslatedData($translation, $key);
    $jobItem->addMessage('Translation received: @translation', ['@translation' => $translation['#text']]);
    $jobItem->save();
  }

}
